*********************************************************************************************************
/*This do-file calculates adopter purchases before and after adoption. In addition, we calculate a 
simulated consumption path for non-mobile users with a sudden spike in activity. These "spikers" answer 
the question of whether the consumption pattern before and after adoption is particular to mobile, or 
whether it is a common pattern surrounding increased purchasing activity.
For more detail, please see the online appendix.*/
*********************************************************************************************************

set more off
clear


foreach mon in Jan Feb Mar Apr May Jun Jul Aug Sep Oct Nov Dec {
	insheet using "`mon' 2012 adopters spikers and others for Figure 4.txt"
	save "`mon' 2012 adopters spikers and others for Figure 4.dta", replace
	clear
}

foreach mon in Jan Feb Mar Apr May Jun Jul Aug Sep Oct Nov Dec {
	/*Match quartiles and deciles of adopter distibution of adoption month purchasing*/
	foreach binnum in 4 10 {
		/*Use three or six month trailing average*/
		foreach trail in /*3*/ 6 {
		
			clear
			use "`mon' 2012 adopters spikers and others for Figure 4.dta", clear
			
			tsset bdr_id purchase_month
			tsfill, full
			
			*Note that months in this analysis are counted from Jan. 2010
			gen spike_month = .
			replace spike_month = 25 if "`mon'"=="Jan"
			replace spike_month = 26 if "`mon'"=="Feb"
			replace spike_month = 27 if "`mon'"=="Mar"
			replace spike_month = 28 if "`mon'"=="Apr"
			replace spike_month = 29 if "`mon'"=="May"
			replace spike_month = 30 if "`mon'"=="Jun"
			replace spike_month = 31 if "`mon'"=="Jul"
			replace spike_month = 32 if "`mon'"=="Aug"
			replace spike_month = 33 if "`mon'"=="Sep"
			replace spike_month = 34 if "`mon'"=="Oct"
			replace spike_month = 35 if "`mon'"=="Nov"
			replace spike_month = 36 if "`mon'"=="Dec"

			/*Study 13 months interval surrounding adoption*/
			drop if purchase_month < spike_month-6 | purchase_month > spike_month+6



			replace mobile_purchases = 0 if mobile_purchases==.
			replace core_purchases = 0 if core_purchases ==.

			
			
			* Fill in the gaps resulting from the tsset method
			bysort bdr_id: egen avg_pre_purchases_tmp = mean(core_purchases) if (purchase_month < spike_month & purchase_month > spike_month-`trail'-1)
			by bdr_id: egen avg_pre_purchases_CORRECT = mean(avg_pre_purchases_tmp)
			by bdr_id: egen adoption_month_tmp = mean(adoption_month)
			replace adoption_month = adoption_month_tmp
			replace months_to_adoption = 100 if adoption_month==100
			replace months_to_adoption = purchase_month - adoption_month if months_to_adoption==. 

			drop avg_pre_purchases_tmp adoption_month_tmp

			*Normalize purchases relative to pre-period average purchases
			gen norm_core_purchases = core_purchases/avg_pre_purchases_CORRECT
			gen norm_mobile_purchases = mobile_purchases/avg_pre_purchases_CORRECT
			gen norm_purchases = (core_purchases+mobile_purchases)/avg_pre_purchases_CORRECT
			
			
			drop if norm_core_purchases==.
			
			bysort bdr_id: gen users_spike_tmp = norm_purchases if purchase_month==spike_month
			by bdr_id: egen users_spike = mean(users_spike_tmp)
			drop users_spike_tmp
			
			drop if users_spike==0
			
			quietly sum norm_purchases if purchase_month==adoption_month, d
			/*Ignore non-adopter activity changes outside of adopter activity change distribution's support*/
			drop if users_spike < r(min) & adoption_month==100
			drop if users_spike > r(max) & adoption_month==100
			
			local nq = `binnum' /*Must be > 1*/
			


			preserve

			keep if months_to_adoption==0 & purchase_month==spike_month
			sort norm_purchases

			gen pct = _n/_N
			local pct_increment = 1/`nq'
			
			*Calculate the quartiles or deciles of the adopter purchasing spike distribution
			forvalues i=1/`nq' {
				local cutoff_tracker = `i'*`pct_increment'
				egen cutoff_tmp = max(norm_purchases) if pct<=`cutoff_tracker'
				egen cutoff_`i' = mean(cutoff_tmp)
				drop cutoff_tmp
				di `cutoff_tracker'
			}

			collapse (mean) cutoff* pctile_lowest_control, by(spike_month)
			save "cutoffs `mon' `nq' groups `trail' trail NEW.dta", replace
			restore
			
			/*Merge data with quartile or decile cutoffs*/
			mmerge spike_month using "cutoffs `mon' `nq' groups `trail' trail NEW.dta", type(n:1) unm(m)
			drop _merge
			
			*Now generate weights for sections of non-adopters' distribution to match adopters' distribution of purchasing spikes
			preserve
			keep if adoption_month==100 & spike_month==purchase_month
			local counter = 1
			gen pctile_group = 1

			*For each non-adopter purchasing spike, determine where it falls in the adopter spike distribution	
			forvalues i=1/`nq' {
				replace pctile_group = `i'+1 if norm_purchases >= cutoff_`i'
			}
			
			
			gen controls = (adoption_month==100)
			egen number_of_spikers = sum(controls)

			*Calculate weights for each percentile group
			gen weight = .
			forvalues i=1/`nq'{
				count if pctile_group == `i' & controls==1
				replace weight = ((100/`nq')/100)/(r(N)/number_of_spikers) if pctile_group==`i'
			}

			
			bysort pctile_group: gen count_in_pct_group = _n


			keep bdr_id pctile_group weight
			save "weights `mon' `nq' groups `trail' trail.dta", replace
			restore
			
			/*Merge with non-adopter weights*/
			mmerge bdr_id using "weights `mon' `nq' groups `trail' trail.dta", type(n:1) unm(m)
			drop _merge
			
			*Drop observations with ridiculous weights resulting from outliers
			drop if weight > 1000 & adoption_month==100

			gen month = purchase_month - spike_month
			gen control = (adoption_month==100)
			bysort month: egen adopter_monthly_core = mean(norm_core_purchases) if control==0
			bysort month: egen adopter_monthly_mobile = mean(norm_mobile_purchases) if control==0

			bysort month control pctile_group: egen weighted_sum_within_pctile = sum(norm_purchase*weight)
			egen total_controls = sum(control)

			bysort pctile_group month: gen pct_counter = _n
			bysort pctile_group: gen pct_counter_total = _n
			bysort pctile_group: egen sum_of_all_weights_tmp = sum(weight) if pct_counter_total==1 & pctile_group~=.
			egen sum_of_all_weights = mean(sum_of_all_weights_tmp)
			bysort month: egen weighted_control_sum_tmp = sum(weighted_sum_within_pctile) if pct_counter==1 & pctile_group ~= .
			bysort month: egen weighted_control_sum = mean(weighted_control_sum_tmp)
			by month: egen num_controls_in_month = sum(control) if control==1
			drop weighted_control_sum_tmp sum_of_all_weights_tmp

			gen weighted_control_avg = (weighted_control_sum)/(num_controls_in_month)

			collapse (mean) adopter_monthly_core adopter_monthly_mobile weighted_control_avg, by(month)
			save "`mon' Weighted Controls and Adopters `binnum' Bins `trail' Trail NEW.dta", replace
		}
	}	
}

foreach binnum in 4 10{
foreach trail in /*3*/ 6 {
foreach mon in Jan Feb Mar Apr May Jun Jul Aug Sep Oct Nov Dec {
	use "`mon' Weighted Controls and Adopters `binnum' Bins `trail' Trail.dta", clear
	rename adopter_monthly_core core_`mon'
	rename adopter_monthly_mobile mobile_`mon'
	rename weighted_control_avg control_`mon'
	save "`mon' Weighted Controls and Adopters `binnum' Bins `trail' Trail.dta", replace
}
}
}


foreach binnum in 4 10{
foreach trail in /*3*/ 6 {
foreach mon in Jan Feb Mar Apr May Jun Jul Aug Sep Oct Nov Dec {
	if "`mon'" == "Jan" {
	use "`mon' Weighted Controls and Adopters `binnum' Bins `trail' Trail NEW.dta", clear
	}
	else {
	mmerge month using "`mon' Weighted Controls and Adopters `binnum' Bins `trail' Trail NEW.dta", type(1:1)
	drop _merge
	}
}
save "All Weighted Controls and Adopters `binnum' Bins `trail' Trail NEW.dta", replace

/*Export adopter and reweighted non-adopter averages for each month. To generate Figures 4 and A2, 
take the adopter weighted average over the months in 2012*/
outsheet using "All Weighted Controls and Adopters `binnum' Bins `trail' Trail NEW.xls", replace
}
}
